@@ -2,7 +2,7 @@
 
 from .auth import Auth
 from .trainer import Trainer
-from .utils.general import PREFIX
+from .yolov5_utils.general import PREFIX
 from .yolov5_wrapper import clone_yolo
 
 AUTH = Auth()
